% function [Freq, AvPowerdBm] = AverageMeasurement_Slow(Signal, Resolution, Fstart, Fstop, Fstep, Tvideo, RBW, R)
% 
% This function provides the average measurement as performed by a spectrum
% analyzer. It is slow, but exact.
% The FCC requirements are RBW = 1MHz and Video Integration Time
% < 1ms
%   Resolution : temporal resolution of Signal    [s] 
%   Tvideo     : Video Integration Time           [s]
%   RBW        : Resolution Bandwidth             [Hz]
%   R          : Characteristic Antenna Impedance [OHm]
%
% Author: samuel.dubouloz@cea.fr,
%         CEA-LETI - May, 2005
% 

function [Freq, AvPowerdBm] = AverageMeasurement_Slow(Signal, Resolution, Fstart, Fstop, Fstep, Tvideo, RBW, R)

if nargin < 5, error('required parameters are missing'),
elseif nargin == 5, R = 50; RBW = 1e6; Tvideo = 1e-3;
elseif nargin == 6, R = 50; RBW = 1e6;
elseif nargin == 7, R = 50; end
if(RBW ~= 1e6 || Tvideo > 1e-3), warning('!!! non FCC compliant conditions !!! '), end

N = round(Tvideo/Resolution);
if length(Signal) < N, error('Signal Duration < Video Integration Time !'), end

Freq = Fstart:Fstep:Fstop;

ww = waitbar(0,'Average Power Measurement - Please Wait...');
for ii = 1:length(Freq),
    waitbar(ii/length(Freq),ww);
    % RBW filter 
    LowFreq = 2 * Resolution * (Freq(ii) - RBW/2);
    UpFreq  = 2 * Resolution * (Freq(ii) + RBW/2);
    [num, den] = butter(2, [LowFreq UpFreq]);
    
    % Signal Filtering
    FilteredSignal = filter(num, den, Signal);
    
    % Integration of Signal over Tvideo
    Measure = 1/(Tvideo) * sum(FilteredSignal(1:N).^2)*Resolution;
    clear FilteredSignal;
    % Conversion in dBm
    AvPowerdBm(ii) = 10*log10(Measure/R) + 30;  
end
close(ww)